@@ -10,8 +10,9 @@
 package Apache::Session::SingleThread;
 
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
+$VERSION = '1.00';
 @ISA = qw(Apache::Session);
 
 use Apache::Session;
